@@ -4,10 +4,10 @@ import matplotlib.pylab as plt
 import uuid
 from . import logs
 
-__version__= '0.0.1'
+import trenchrun
 
 import numpy as np
-import sys
+import numpy.ma as ma
 from osgeo import gdal
 gdal.UseExceptions()
 
@@ -25,7 +25,11 @@ def readBand(filename,
         array = (array - array.min()) / (array.max() - array.min())
 
     # mask off any nodata values
-    array[array==band.GetNoDataValue()] = np.nan
+    nodata = band.GetNoDataValue()
+    logs.logger.info(f'nodata value: {nodata} for resource {filename}')
+    nans = np.count_nonzero(array == nodata)
+    array[array==nodata] = np.nan
+    array = np.ma.array (array, mask=np.isnan(array))
     return array
 
 def getInfo(filename):
@@ -34,38 +38,45 @@ def getInfo(filename):
     projection = ds.GetProjection()
     output['projection'] = ds.GetProjection()
     output['metadata'] = ds.GetMetadata()
+    output['transform'] = ds.GetGeoTransform()
     return output
-    ds.GetMetadata()
-    return projection
 
 class Blend(object):
     def __init__(self, data):
         self.data = data
 
     def do(self):
-        intensityFilename = self.data.args.intensityPath
-        daylightFilename = self.data.args.aoPath
+        intensityFilename = str(self.data.args.intensityPath)
+        daylightFilename = str(self.data.args.aoPath)
         intensity = readBand(intensityFilename, 1, np.float32, True)
         daylight = readBand(daylightFilename, 1)
 
         logs.logger.info(f'Intensity shape {intensity.shape} ')
         logs.logger.info(f'Daylight shape {intensity.shape} ')
 
+        intensity_mask = ma.getmask(intensity)
+        daylight_mask = ma.getmask(daylight)
         if self.data.args.blue:
-            intensity_RGBA = mpl.cm.Blues_r(intensity)
+            cmap = mpl.cm.Blues_r
         else:
-            intensity_RGBA = mpl.cm.Greys_r(intensity)
+            cmap = mpl.cm.Greys_r
 
+        intensity_RGBA = cmap(intensity)
         intensity_RGBA[...,3] = np.full(intensity.shape, self.data.args.alpha)
 
-        daylight_RGB = mpl.cm.Greys_r(daylight)
+        cmap = mpl.cm.Greys_r
+        daylight_RGB = cmap(daylight)
 
         RGBA = intensity_RGBA * 0.5 + daylight_RGB * 0.5
 
         numBands = RGBA.shape[2]
 
+
+        nodata = 255
         big = (RGBA*255).astype(np.uint8)
-        logs.logger.info(f'RGBA shape {big.shape} ')
+        for i in range(numBands):
+            ma.putmask(big[...,i], intensity_mask, nodata)
+            ma.putmask(big[...,i], daylight_mask, nodata)
 
         tifpath = f"/vsimem/{str(uuid.uuid4())}.tif"
         gtif = gdal.GetDriverByName("GTiff")
@@ -74,29 +85,41 @@ class Blend(object):
         info = getInfo(intensityFilename)
 
         rast.SetProjection(info['projection'])
+        rast.SetGeoTransform(info['transform'])
 
         for b in range(numBands):
-            rast.GetRasterBand(b+1).WriteArray(big[...,b])
+            band =rast.GetRasterBand(b+1)
+            band.WriteArray(big[...,b])
+            band.SetNoDataValue(nodata)
 
         png = gdal.GetDriverByName("PNG")
 
         description='daylight exposure mixed with lidar intensity'
         title = 'Absorptive Daylight Exposure'
-        png.CreateCopy( f"{self.data.args.output}.png", rast, 0,
-            [ f'TITLE={title}', f'COMMENT={description}' ] )
 
-        ds = gtif.CreateCopy( f"{self.data.args.output}.tif", rast, 0,
+        if self.data.args.full_output:
+            png.CreateCopy( f"{self.data.args.output}-trenchrun.png", rast, 0,
+                [ f'TITLE={title}', f'COMMENT={description}' ] )
+
+        ds = gtif.CreateCopy( f"{self.data.args.output}-trenchrun.tif", rast, 0,
             [ 'COMPRESS=Deflate', 'TILED=YES','PREDICTOR=2' ] )
 
-
         if 'AREA_OR_POINT' in info['metadata']:
             ds.SetMetadataItem('AREA_OR_POINT', info['metadata']['AREA_OR_POINT'])
 
-        ds.SetMetadataItem('TIFFTAG_SOFTWARE',f'Landrush exposure.py {__version__}')
+        ds.SetMetadataItem('TIFFTAG_SOFTWARE',f'Trenchrun {trenchrun.__version__}')
         ds.SetMetadataItem('TIFFTAG_IMAGEDESCRIPTION',f'{description}')
         ds.SetMetadataItem('TIFFTAG_DOCUMENTNAME',f'{title}')
 
-        ao = gdal.Open(self.data.args.aoPath)
-        ds = gtif.CreateCopy( f"{self.data.args.output}-occlusion.tif", ao, 0,
-            [ 'COMPRESS=Deflate', 'TILED=YES','PREDICTOR=2' ] )
+        if self.data.args.full_output:
+            ao = gdal.Open(str(self.data.args.aoPath))
+            ds = gtif.CreateCopy( f"{self.data.args.output}-occlusion.tif", ao, 0,
+                [ 'COMPRESS=Deflate', 'TILED=YES','PREDICTOR=2' ] )
 
+            ao = gdal.Open(str(self.data.args.dsmPath))
+            ds = gtif.CreateCopy( f"{self.data.args.output}-dsm.tif", ao, 0,
+                [ 'COMPRESS=LZW', 'TILED=YES','PREDICTOR=3' ] )
+
+            ao = gdal.Open(str(self.data.args.intensityPath))
+            ds = gtif.CreateCopy( f"{self.data.args.output}-intensity.tif", ao, 0,
+                [ 'COMPRESS=LZW', 'TILED=YES','PREDICTOR=2' ] )
